import type { FieldStatsType } from '../models/FieldStatsType';
import type { FieldValuesStats } from '../models/FieldValuesStats';
import type { FieldValuesStatsList } from '../models/FieldValuesStatsList';
import type { GzipStats } from '../models/GzipStats';
import type { ListSizes } from '../models/ListSizes';
import type { ListSizesList } from '../models/ListSizesList';
import type { CancelablePromise } from '../core/CancelablePromise';
export declare class StatsService {
    /**
     * Study Sizes
     * Statistics of study JSON sizes.
     * @returns GzipStats OK
     * @throws ApiError
     */
    static sizeStats(): CancelablePromise<GzipStats>;
    /**
     * Values Stats
     * Value statistics of the study leaf fields.
     * @returns FieldValuesStatsList OK
     * @throws ApiError
     */
    static fieldValuesSummary({ types, }: {
        types?: Array<FieldStatsType>;
    }): CancelablePromise<FieldValuesStatsList>;
    /**
     * Field Values Stats
     * Value statistics of a single study leaf field.
     * @returns FieldValuesStats OK
     * @throws ApiError
     */
    static fieldValuesStats({ field, }: {
        /**
         * Piece name or field path. See [Data Structure](/study-data-structure) for the available values.
         */
        field: string;
    }): CancelablePromise<FieldValuesStats>;
    /**
     * List Sizes
     * Sizes of all list/array fields.
     *
     * To search studies by a list field size, use `AREA[FieldName:size]` search operator.
     * For example, [AREA\[Phase:size\] 2](https://clinicaltrials.gov/search?term=AREA%5BPhase:size%5D%202)
     * query finds studies with 2 phases.
     * @returns ListSizesList OK
     * @throws ApiError
     */
    static listSizesSummary(): CancelablePromise<ListSizesList>;
    /**
     * List Field Sizes
     * Sizes of list/array field.
     *
     * To search studies by a list field size, use `AREA[FieldName:size]` search operator.
     * For example, [AREA\[SubmissionInfo:size\] 15](https://clinicaltrials.gov/search?term=AREA%5BSubmissionInfo:size%5D%2015)
     * query finds studies where SubmissionInfo list size is 15.
     * @returns ListSizes OK
     * @throws ApiError
     */
    static listSizes({ field, }: {
        /**
         * Piece name or field path. See [Data Structure](/study-data-structure) for the available values.
         */
        field: string;
    }): CancelablePromise<ListSizes>;
}
