"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatsService = void 0;
const OpenAPI_1 = require("../core/OpenAPI");
const request_1 = require("../core/request");
class StatsService {
    /**
     * Study Sizes
     * Statistics of study JSON sizes.
     * @returns GzipStats OK
     * @throws ApiError
     */
    static sizeStats() {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/stats/size',
            errors: {
                400: `Bad request`,
            },
        });
    }
    /**
     * Values Stats
     * Value statistics of the study leaf fields.
     * @returns FieldValuesStatsList OK
     * @throws ApiError
     */
    static fieldValuesSummary({ types, }) {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/stats/fieldValues',
            query: {
                'types': types,
            },
            errors: {
                400: `Bad request`,
                404: `Not found`,
            },
        });
    }
    /**
     * Field Values Stats
     * Value statistics of a single study leaf field.
     * @returns FieldValuesStats OK
     * @throws ApiError
     */
    static fieldValuesStats({ field, }) {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/stats/fieldValues/{field}',
            path: {
                'field': field,
            },
            errors: {
                400: `Bad request`,
                404: `Not found`,
            },
        });
    }
    /**
     * List Sizes
     * Sizes of all list/array fields.
     *
     * To search studies by a list field size, use `AREA[FieldName:size]` search operator.
     * For example, [AREA\[Phase:size\] 2](https://clinicaltrials.gov/search?term=AREA%5BPhase:size%5D%202)
     * query finds studies with 2 phases.
     * @returns ListSizesList OK
     * @throws ApiError
     */
    static listSizesSummary() {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/stats/listSizes',
            errors: {
                400: `Bad request`,
                404: `Not found`,
            },
        });
    }
    /**
     * List Field Sizes
     * Sizes of list/array field.
     *
     * To search studies by a list field size, use `AREA[FieldName:size]` search operator.
     * For example, [AREA\[SubmissionInfo:size\] 15](https://clinicaltrials.gov/search?term=AREA%5BSubmissionInfo:size%5D%2015)
     * query finds studies where SubmissionInfo list size is 15.
     * @returns ListSizes OK
     * @throws ApiError
     */
    static listSizes({ field, }) {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/stats/listSizes/{field}',
            path: {
                'field': field,
            },
            errors: {
                400: `Bad request`,
                404: `Not found`,
            },
        });
    }
}
exports.StatsService = StatsService;
